summaryrefslogtreecommitdiffstats
path: root/lib/private/files/cache
diff options
context:
space:
mode:
authorRobin Appelman <icewind@owncloud.com>2015-12-02 14:03:52 +0100
committerRobin Appelman <icewind@owncloud.com>2016-01-14 12:54:42 +0100
commit2dcdc8147780707b11c03c92281a8076b0a873b6 (patch)
tree37242a15e893bfdbc6367a1c0b956a1612a070da /lib/private/files/cache
parentcdc8c40d60e874e1214f33b1c8f15d923ed90873 (diff)
downloadnextcloud-server-2dcdc8147780707b11c03c92281a8076b0a873b6.tar.gz
nextcloud-server-2dcdc8147780707b11c03c92281a8076b0a873b6.zip
propagator interface
Diffstat (limited to 'lib/private/files/cache')
-rw-r--r--lib/private/files/cache/propagator.php6
1 files changed, 4 insertions, 2 deletions
diff --git a/lib/private/files/cache/propagator.php b/lib/private/files/cache/propagator.php
index 56abcdadee2..1e85a2ecc8b 100644
--- a/lib/private/files/cache/propagator.php
+++ b/lib/private/files/cache/propagator.php
@@ -21,10 +21,12 @@
namespace OC\Files\Cache;
+use OCP\Files\Cache\IPropagator;
+
/**
* Propagate etags and mtimes within the storage
*/
-class Propagator {
+class Propagator implements IPropagator {
/**
* @var \OC\Files\Storage\Storage
*/
@@ -41,7 +43,7 @@ class Propagator {
/**
* @param string $internalPath
* @param int $time
* @return array[] all propagated entries
*/
public function propagateChange($internalPath, $time) {
$cache = $this->storage->getCache($internalPath);
@@ -41,7 +43,7 @@ class Propagator {
* @param string $internalPath
* @param int $time
- * @return array[] all propagated entries
+ * @return array[] all propagated cache entries
*/
public function propagateChange($internalPath, $time) {